@@ -31,7 +31,7 @@ std::vector<double> linspace(int start, int end, int n);
 void run_simulation(Prms &p, 
                     std::vector<double> &activation_sum, 
                     std::vector<std::vector<double>> &trial_matrix, 
-                    std::vector<double> &mu_vec, 
+                    std::vector<double> &u_vec, 
                     std::vector<double> &sp, 
                     std::vector<double> &dr, 
                     std::vector<double> &rts, 
@@ -39,7 +39,7 @@ void run_simulation(Prms &p,
                     int sign);
 
 void run_simulation(Prms &p, 
-                    std::vector<double> &mu_vec, 
+                    std::vector<double> &u_vec, 
                     std::vector<double> &sp, 
                     std::vector<double> &dr, 
                     std::vector<double> &rts, 
